aboutsummaryrefslogtreecommitdiff
path: root/release/scripts/manpages-make.sh
diff options
context:
space:
mode:
Diffstat (limited to 'release/scripts/manpages-make.sh')
-rwxr-xr-xrelease/scripts/manpages-make.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/release/scripts/manpages-make.sh b/release/scripts/manpages-make.sh
index fae9dd3487b7..bb1326f3d506 100755
--- a/release/scripts/manpages-make.sh
+++ b/release/scripts/manpages-make.sh
@@ -3,10 +3,10 @@
# $FreeBSD$
#
# Move all the manpages out to their own dist, using the bin dist as a
# starting point.
-if [ -d ${RD}/trees/bin/usr/share/man ]; then
- ( cd ${RD}/trees/bin/usr/share/man;
+if [ -d ${RD}/trees/base/usr/share/man ]; then
+ ( cd ${RD}/trees/base/usr/share/man;
find . | cpio -dumpl ${RD}/trees/manpages/usr/share/man > /dev/null 2>&1) &&
- rm -rf ${RD}/trees/bin/usr/share/man;
+ rm -rf ${RD}/trees/base/usr/share/man;
fi
@@ -3,10 +3,10 @@
# $FreeBSD$
#
-# Move all the manpages out to their own dist, using the bin dist as a
+# Move all the manpages out to their own dist, using the base dist as a
# starting point.